@@ -43,7 +43,7 @@
 #endif /* HAVE_CONFIG_H */
 
 #ifdef AUTH_OTHER
-static const char rcsid[] = "$Id: auth_other.c,v 1.1 2001/04/23 23:45:40 chris Exp $";
+static const char rcsid[] = "$Id: auth_other.c,v 1.4 2001/05/03 00:20:56 chris Exp $";
 
 #include <sys/types.h>
 
@@ -72,7 +72,7 @@ char *auth_program;
 time_t authchild_start_time;
 uid_t authchild_uid;
 gid_t authchild_gid;
-pid_t authchild_pid;
+volatile pid_t authchild_pid;
 struct timeval authchild_timeout;
 
 /* File descriptors used to talk to child. */
@@ -96,8 +96,6 @@ void dump(unsigned char *b, size_t len) {
     free(str);
 }
 
-
-
 /* tvadd:
  * t1 += t2 on timevals.
  */
@@ -142,7 +140,8 @@ int tvcmp(const struct timeval *t1, const struct timeval *t2) {
 int auth_other_start_child() {
     int p1[2], p2[2];
     char *argv[2] = {auth_program, NULL};
-    char *envp[2] = {"PATH=/bin", NULL};    /* Very restrictive path. */
+    char *envp[2] = {"PATH=/bin",  /* XXX path? */
+                     "TPOP3D_CONTEXT=auth_other", NULL};
 
     /* Generate pipes to talk to the child. */
     if (pipe(p1) == -1 || pipe(p2) == -1) {
@@ -318,7 +317,7 @@ void auth_other_close() {
  * Send the auth child a request consisting of several key/value pairs, as
  * above. Returns 1 on success or 0 on failure.
  */
-int auth_other_send_request(int nvars, ...) {
+int auth_other_send_request(const int nvars, ...) {
     va_list ap;
     int i, ret = 0;
     char buffer[MAX_DATA_SIZE] = {0};
@@ -532,13 +531,17 @@ fail:
  * Attempt to authenticate a user using USER/PASS, via the child program.
  */
 authcontext auth_other_new_user_pass(const char *user, const char *pass) {
-#define MISSING(k)     do { print_log(LOG_ERR, _("auth_other_new_apop: missing key `%s' in response"), (k)); goto fail; } while(0)
-#define INVALID(k, v)  do { print_log(LOG_ERR, _("auth_other_new_apop: invalid value `%s' for key `%s' in response"), (v), (k)); goto fail; } while(0)
+#define MISSING(k)     do { print_log(LOG_ERR, _("auth_other_new_user_pass: missing key `%s' in response"), (k)); goto fail; } while(0)
+#define INVALID(k, v)  do { print_log(LOG_ERR, _("auth_other_new_user_pass: invalid value `%s' for key `%s' in response"), (v), (k)); goto fail; } while(0)
     stringmap S;
     item *I;
     authcontext a = NULL;
 
     if (!authchild_pid) auth_other_start_child();
+
+    if (!auth_other_send_request(3, "method", "PASS", "user", user, "pass", pass)
+        || !(S = auth_other_recv_response()))
+        return NULL;
     
     I = stringmap_find(S, "logmsg");
     if (I) print_log(LOG_INFO, "auth_other_new_user_pass: child: %s", (char*)I->v);
