@@ -9,7 +9,7 @@
  *
  */
 
-static const char rcsid[] = "$Id: cfgdirectives.c,v 1.4 2001/04/23 23:45:40 chris Exp $";
+static const char rcsid[] = "$Id: cfgdirectives.c,v 1.5 2001/04/26 23:30:03 chris Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "configuration.h"
@@ -57,6 +57,14 @@ char *cfgdirectives[] = {
     "auth-other-group",
     "auth-other-timeout",
 #endif /* AUTH_OTHER */
+ 
+#ifdef AUTH_PERL
+    "auth-perl-enable",
+    "auth-perl-start",
+    "auth-perl-finish",
+    "auth-perl-apop",
+    "auth-perl-pass",
+#endif /* AUTH_PERL */
     
     /* final entry must be NULL */
     NULL};
