@@ -6,7 +6,7 @@
  *
  */
 
-static const char rcsid[] = "$Id: util.c,v 1.4 2001/04/23 23:45:40 chris Exp $";
+static const char rcsid[] = "$Id: util.c,v 1.5 2001/04/24 14:25:34 chris Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include "configuration.h"
@@ -92,7 +92,7 @@ int daemon(int nochdir, int noclose) {
     return 0;
 }
 
-#ifdef __SVR4
+#ifndef HAVE_INET_ATON
 /* inet_aton:
  * Implementation of inet_aton for machines (Solaris [cough]) which do not
  * have it.
@@ -103,7 +103,7 @@ int inet_aton(const char *s, struct in_addr *ip) {
     memcpy(ip, &i, sizeof(int));                                                
     return 1;                                                                   
 }                                                                               
-#endif
+#endif /* !HAVE_INET_ATON */
 
 /* write_file:
  * Send to socket sck the header and up to n lines of the body of a message
